@@ -1,6 +1,7 @@
 // cmdline_resolver.cc
 //
 //   Copyright (C) 2005-2010 Daniel Burrows
+//   Copyright (C) 2014-2018 Manuel A. Fernandez Montecelo
 //
 //   This program is free software; you can redistribute it and/or
 //   modify it under the terms of the GNU General Public License as
@@ -14,8 +15,8 @@
 //
 //   You should have received a copy of the GNU General Public License
 //   along with this program; see the file COPYING.  If not, write to
-//   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-//   Boston, MA 02111-1307, USA.
+//   the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+//   Boston, MA 02110-1301, USA.
 
 
 // Local includes:
@@ -43,27 +44,20 @@
 
 
 // System includes:
-#include <boost/lexical_cast.hpp>
-#include <boost/make_shared.hpp>
-#include <boost/ref.hpp>
-#include <boost/shared_ptr.hpp>
-
 #include <cwidget/fragment.h>
 #include <cwidget/generic/util/ssprintf.h>
 
 #include <apt-pkg/error.h>
 #include <apt-pkg/strutl.h>
 
-#include <iostream>
-#include <fstream>
-#include <sstream>
-
 #include <algorithm>
+#include <fstream>
+#include <iostream>
+#include <sstream>
 
 using namespace std;
 
 using aptitude::cmdline::terminal_metrics;
-using boost::shared_ptr;
 
 typedef generic_solution<aptitude_universe> aptitude_solution;
 typedef generic_choice<aptitude_universe> choice;
@@ -108,7 +102,7 @@ static cw::fragment *solution_story(const aptitude_solution &s,
 
       for(std::vector<choice>::size_type i = 0; i < choices.size(); ++i)
 	{
-	  std::string key = boost::lexical_cast<std::string>(i + 1);
+	  std::string key = std::to_string(i + 1);
 	  id_fragments.push_back(NULL);
 	  id_fragments.push_back(cw::fragf("%s)", key.c_str()));
 	  (*ids)[key] = choices[i];
@@ -216,7 +210,7 @@ static inline cw::fragment *flowindentbox(int i1, int irest, cw::fragment *f)
 }
 
 static void resolver_help(ostream &out,
-                          const shared_ptr<terminal_metrics> &term_metrics)
+                          const std::shared_ptr<terminal_metrics> &term_metrics)
 {
   cw::fragment *f=indentbox(2, 2,
 			cw::fragf(_("y: %F"
@@ -242,7 +236,7 @@ static void resolver_help(ostream &out,
 			      flowindentbox(0, 3,
 					    cw::fragf(_("accept the proposed changes"))),
 			      flowindentbox(0, 3,
-					    cw::fragf(_("reject the proposed changes and search for another solution"))),
+					    cw::fragf(_("jump to the end of all the generated solutions and search for another"))),
 			      flowindentbox(0, 3,
 					    cw::fragf(_("give up and quit the program"))),
 			      flowindentbox(0, 3,
@@ -303,7 +297,7 @@ static pkgCache::VerIterator choose_version(const vector<pkgCache::VerIterator>
 
   while(1)
     {
-      string response = prompt_string(ssprintf(_("Select the version of %s that should be used: "), choices.front().ParentPkg().Name()));
+      string response = prompt_string(ssprintf(_("Select the version of %s that should be used: "), choices.front().ParentPkg().FullName(true).c_str()));
 
       int i;
       istringstream in(response);
@@ -401,10 +395,10 @@ static void reject_or_mandate_version(const string &s,
 		  {
 		    if(ver.get_ver().end())
 		      cout << ssprintf(_("Allowing the removal of %s"),
-				       pkg.Name()) << endl;
+				       pkg.FullName(true).c_str()) << endl;
 		    else
 		      cout << ssprintf(_("Allowing the installation of %s version %s (%s)"),
-				       pkg.Name(),
+				       pkg.FullName(true).c_str(),
 				       ver.get_ver().VerStr(),
 				       archives_text(ver.get_ver()).c_str()) << endl;
 
@@ -414,10 +408,10 @@ static void reject_or_mandate_version(const string &s,
 		  {
 		    if(ver.get_ver().end())
 		      cout << ssprintf(_("Rejecting the removal of %s"),
-				       pkg.Name()) << endl;
+				       pkg.FullName(true).c_str()) << endl;
 		    else
 		      cout << ssprintf(_("Rejecting the installation of %s version %s (%s)"),
-				       pkg.Name(),
+				       pkg.FullName(true).c_str(),
 				       ver.get_ver().VerStr(),
 				       archives_text(ver.get_ver()).c_str()) << endl;
 
@@ -430,10 +424,10 @@ static void reject_or_mandate_version(const string &s,
 		  {
 		    if(ver.get_ver().end())
 		      cout << ssprintf(_("No longer requiring the removal of %s"),
-				       pkg.Name()) << endl;
+				       pkg.FullName(true).c_str()) << endl;
 		    else
 		      cout << ssprintf(_("No longer requiring the installation of %s version %s (%s)"),
-				       pkg.Name(), ver.get_ver().VerStr(),
+				       pkg.FullName(true).c_str(), ver.get_ver().VerStr(),
 				       archives_text(ver.get_ver()).c_str()) << endl;
 
 		    resman->unmandate_version(ver);
@@ -442,10 +436,10 @@ static void reject_or_mandate_version(const string &s,
 		  {
 		    if(ver.get_ver().end())
 		      cout << ssprintf(_("Requiring the removal of %s"),
-				       pkg.Name()) << endl;
+				       pkg.FullName(true).c_str()) << endl;
 		    else
 		      cout << ssprintf(_("Requiring the installation of %s version %s (%s)"),
-				       pkg.Name(), ver.get_ver().VerStr(),
+				       pkg.FullName(true).c_str(), ver.get_ver().VerStr(),
 				       archives_text(ver.get_ver()).c_str()) << endl;
 
 		    resman->mandate_version(ver);
@@ -466,7 +460,7 @@ static void reject_or_mandate_version(const string &s,
 	      dep_rendering_stream << "(??\?)";
 	    else
 	      {
-		dep_rendering_stream << start.ParentPkg().Name()
+		dep_rendering_stream << start.ParentPkg().FullName(true)
 				     << " "
 				     << start.ParentVer().VerStr()
 				     << " "
@@ -481,7 +475,7 @@ static void reject_or_mandate_version(const string &s,
 		    else
 		      dep_rendering_stream << " | ";
 
-		    dep_rendering_stream << start.TargetPkg().Name()
+		    dep_rendering_stream << start.TargetPkg().FullName(true)
 					 << " "
 					 << start.TargetVer();
 
@@ -527,7 +521,7 @@ static void reject_or_mandate_version(const string &s,
 
 void cmdline_resolver_show_choice(const choice &c,
 				  const std::string &tag,
-                                  const shared_ptr<terminal_metrics> &term_metrics)
+                                  const std::shared_ptr<terminal_metrics> &term_metrics)
 {
   cw::fragment *info_fragment = NULL;
   bool is_rejected = false;
@@ -547,7 +541,7 @@ void cmdline_resolver_show_choice(const choice &c,
 
         if(disp_ver.end())
           info_fragment = cw::fragf("Package: %s\n\n",
-                                    c.get_ver().get_pkg().Name());
+                                    c.get_ver().get_pkg().FullName(true).c_str());
         else
           info_fragment = cw::fragf("%F\n\n",
                                     version_file_fragment(disp_ver,
@@ -583,7 +577,7 @@ void cmdline_resolver_show_choice(const choice &c,
                                 // traditional way and maybe explain
                                 // which part failed?
                                 //
-                                // ForTranslators: the substitution is
+                                // TRANSLATORS: the substitution is
                                 // replaced in English with something
                                 // like "Pkg1 depends upon Pkg2".
                                 cw::fragf(_("This action was selected because %ls."),
@@ -591,25 +585,25 @@ void cmdline_resolver_show_choice(const choice &c,
 				is_rejected ? cw::fragf("%s\n", _("This action is currently rejected; it will not appear in new solutions.")) :
 				is_approved ? cw::fragf("%s\n", _("This action is currently approved; it will be selected whenever possible.")) :
 				cw::text_fragment(""),
-				// ForTranslators: the "r" here is
+				// TRANSLATORS: the "r" here is
 				// for "reject", but should not be
 				// translated since the commands in
 				// aptitude's internal command-line
 				// aren't translated.
 				is_rejected ? cw::fragf(_("Enter \"r %s\" to allow this action to appear in new solutions."), tag.c_str())
-				// ForTranslators: the "r" here is
+				// TRANSLATORS: the "r" here is
 				// for "reject", but should not be
 				// translated since the commands in
 				// aptitude's internal command-line
 				// aren't translated.
                                             : cw::fragf(_("Enter \"r %s\" to prevent this action from appearing in new solutions."), tag.c_str()),
-				// ForTranslators: the "a" here is
+				// TRANSLATORS: the "a" here is
 				// for "approve", but should not be
 				// translated since the commands in
 				// aptitude's internal command-line
 				// aren't translated.
 				is_approved ? cw::fragf(_("Enter \"a %s\" to cease requiring that new solutions include this action if possible."), tag.c_str())
-				// ForTranslators: the "a" here is
+				// TRANSLATORS: the "a" here is
 				// for "approve", but should not be
 				// translated since the commands in
 				// aptitude's internal command-line
@@ -806,12 +800,12 @@ static aptitude_solution wait_for_solution(cwidget::threads::box<cmdline_resolve
 }
 
 aptitude_solution calculate_current_solution(bool suppress_message,
-                                             const shared_ptr<terminal_metrics> &term_metrics)
+                                             const std::shared_ptr<terminal_metrics> &term_metrics)
 {
   const int step_limit = aptcfg->FindI(PACKAGE "::ProblemResolver::StepLimit", 5000);
   if(step_limit <= 0)
     {
-      const std::string msg = ssprintf(_("Would resolve dependencies, but dependency resolution is disabled.\n   (%s::ProblemResolver::StepLimit = 0)\n"), PACKAGE);
+      const std::string msg = ssprintf(_("Would resolve dependencies, but dependency resolution is disabled.\n   (%s::ProblemResolver::StepLimit <= 0)\n"), PACKAGE);
 
       // It's important that the code path leading to here doesn't
       // access resman: the resolver won't exist in this case.
@@ -825,8 +819,6 @@ aptitude_solution calculate_current_solution(bool suppress_message,
       throw CmdlineSearchAbortedException(msg);
     }
 
-
-
   if(resman->get_selected_solution() < resman->generated_solution_count())
     return resman->get_solution(resman->get_selected_solution(), 0);
 
@@ -840,7 +832,7 @@ aptitude_solution calculate_current_solution(bool suppress_message,
 
   resman->get_solution_background(resman->generated_solution_count(),
 				  step_limit,
-				  boost::make_shared<cmdline_resolver_continuation>(boost::ref(retbox)),
+				  std::make_shared<cmdline_resolver_continuation>(std::ref(retbox)),
 				  cmdline_resolver_trampoline);
 
   return wait_for_solution(retbox, spin);
@@ -856,7 +848,7 @@ cmdline_resolve_deps(pkgset &to_install,
 		     int verbose,
 		     pkgPolicy &policy,
 		     bool arch_only,
-                     const shared_ptr<terminal_metrics> &term_metrics)
+                     const std::shared_ptr<terminal_metrics> &term_metrics)
 {
   bool story_is_default = aptcfg->FindB(PACKAGE "::CmdLine::Resolver-Show-Steps", false);
 
@@ -930,11 +922,12 @@ cmdline_resolve_deps(pkgset &to_install,
 		    modified_pkgs=true;
 		    break;
 		  case 'N':
+		    // jump to the end of the solutions and generate new ones
 		    {
 		      unsigned int curr_count = resman->generated_solution_count();
 
-		      if(curr_count>0)
-			while(resman->get_selected_solution() < curr_count)
+		      if (curr_count > 0)
+			while (resman->get_selected_solution() < curr_count)
 			  resman->select_next_solution();
 		    }
 		    break;
@@ -958,7 +951,13 @@ cmdline_resolve_deps(pkgset &to_install,
 		      break;
 		    }
 		  case 'E':
-		    ui_solution_screen();
+		    {
+		      // prevent curses if dumb term -- see #317928, #817276
+		      if (aptitude::util::is_dumb_terminal())
+			aptitude::util::print_ncurses_dumb_terminal();
+		      else
+			ui_solution_screen();
+		    }
 		    break;
 		  case 'R':
 		    reject_or_mandate_version(string(response, 1), ids, true);
@@ -1040,7 +1039,7 @@ cmdline_resolve_deps(pkgset &to_install,
 		    break;
 		  }
 	      }
-	    catch(NoMoreTime)
+	    catch(const NoMoreTime&)
 	      {
 		bool done=false;
 		while(!done)
@@ -1067,7 +1066,7 @@ cmdline_resolve_deps(pkgset &to_install,
 			    calculate_current_solution(false, term_metrics);
 			    done=true;
 			  }
-			catch(NoMoreTime)
+			catch(const NoMoreTime&)
 			  {
 			    // ignore and continue looping.
 			  }
@@ -1082,7 +1081,7 @@ cmdline_resolve_deps(pkgset &to_install,
 		  }
 	      }
 	  }
-	catch(NoMoreSolutions)
+	catch(const NoMoreSolutions&)
 	  {
 	    if(resman->generated_solution_count()==0)
 	      {
@@ -1100,7 +1099,7 @@ cmdline_resolve_deps(pkgset &to_install,
 		lastsol.nullify();
 	      }
 	  }
-	catch(StdinEOFException)
+	catch(const StdinEOFException&)
 	  {
 	    throw;
 	  }
@@ -1140,14 +1139,14 @@ namespace aptitude
   {
     // Implements the --show-resolver-actions command-line parameters.
     void show_resolver_actions(const generic_solution<aptitude_universe> &solution,
-                               const shared_ptr<terminal_metrics> &term_metrics)
+                               const std::shared_ptr<terminal_metrics> &term_metrics)
     {
       if(solution.get_choices().size() > 0)
 	{
 	  // The previous line will say "resolving dependencies...";
 	  // separate the solution from this message..
 	  std::cout << std::endl;
-	  std::auto_ptr<cw::fragment> story(solution_story(solution, NULL));
+	  std::unique_ptr<cw::fragment> story(solution_story(solution, NULL));
           const unsigned int screen_width = term_metrics->get_screen_width();
 	  std::cout << story->layout(screen_width, screen_width, cwidget::style());
 	}
@@ -1159,7 +1158,7 @@ namespace aptitude
                            bool no_new_installs,
                            bool no_new_upgrades,
                            bool show_story,
-                           const shared_ptr<terminal_metrics> &term_metrics)
+                           const std::shared_ptr<terminal_metrics> &term_metrics)
     {
       if(!resman->resolver_exists())
 	return true;
@@ -1171,7 +1170,7 @@ namespace aptitude
 	  cwidget::threads::box<cmdline_resolver_continuation::resolver_result> retbox;
 
 	  resman->safe_resolve_deps_background(no_new_installs, no_new_upgrades,
-					       boost::make_shared<cmdline_resolver_continuation>(boost::ref(retbox)),
+					       std::make_shared<cmdline_resolver_continuation>(std::ref(retbox)),
 					       cmdline_resolver_trampoline);
 
 	  cmdline_spinner spin(aptcfg->FindI("Quiet", 0), term_metrics);
@@ -1186,7 +1185,7 @@ namespace aptitude
 	  (*apt_cache_file)->apply_solution(sol, NULL);
 	}
       // If anything goes wrong, we give up (silently if verbosity is disabled).
-      catch(NoMoreTime)
+      catch(const NoMoreTime&)
 	{
 	  std::cout << cw::util::ssprintf(_("Unable to resolve dependencies for the upgrade because the resolver timed out.\n  You may be able to solve this problem by increasing\n  Aptitude::ProblemResolver::StepLimit (currently %d)."),
 					  // TODO: bad magic number
@@ -1196,7 +1195,7 @@ namespace aptitude
 		    << std::endl;
 	  return false;
 	}
-      catch(NoMoreSolutions)
+      catch(const NoMoreSolutions&)
 	{
 	  std::cout << _("Unable to resolve dependencies for the upgrade: no solution found.")
 		    << std::endl;
