@@ -1,6 +1,7 @@
 // download_manager.cc
 //
 //   Copyright (C) 2005 Daniel Burrows
+//   Copyright (C) 2016 Manuel A. Fernandez Montecelo
 //
 //   This program is free software; you can redistribute it and/or
 //   modify it under the terms of the GNU General Public License as
@@ -14,13 +15,13 @@
 //
 //   You should have received a copy of the GNU General Public License
 //   along with this program; see the file COPYING.  If not, write to
-//   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-//   Boston, MA 02111-1307, USA.
+//   the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+//   Boston, MA 02110-1301, USA.
 
 #include "download_manager.h"
 
-download_manager::download_manager()
-  : fetcher(NULL)
+download_manager::download_manager() :
+  fetcher { nullptr }
 {
 }
 
