@@ -1,6 +1,7 @@
 // match.h    -*-c++-*-
 //
 //   Copyright (C) 2008-2010 Daniel Burrows
+//   Copyright (C) 2014-2016 Manuel A. Fernandez Montecelo
 //
 //   This program is free software; you can redistribute it and/or
 //   modify it under the terms of the GNU General Public License as
@@ -14,8 +15,8 @@
 //
 //   You should have received a copy of the GNU General Public License
 //   along with this program; see the file COPYING.  If not, write to
-//   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-//   Boston, MA 02111-1307, USA.
+//   the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+//   Boston, MA 02110-1301, USA.
 
 #ifndef MATCH_H
 #define MATCH_H
@@ -267,6 +268,17 @@ namespace aptitude
 			 (regexp_match *)0, (regexp_match *)0);
       }
 
+      static cwidget::util::ref_ptr<match> make_atomic(const cwidget::util::ref_ptr<pattern> &p,
+						       const std::string &match_string)
+      {
+	return new match(atomic, p,
+			 cwidget::util::ref_ptr<structural_match>(),
+			 pkgCache::DepIterator(),
+			 pkgCache::PrvIterator(),
+			 match_string,
+			 (regexp_match *)0, (regexp_match *)0);
+      }
+
       /** \brief Create a new regular expression match.
        *
        *  \param p  The pattern that produced this match.
