@@ -14,24 +14,28 @@
 
 //   You should have received a copy of the GNU General Public License
 //   along with this program; see the file COPYING.  If not, write to
-//   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-//   Boston, MA 02111-1307, USA.
+//   the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+//   Boston, MA 02110-1301, USA.
 
 #ifndef SQLITE_H
 #define SQLITE_H
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include <cwidget/generic/threads/threads.h>
 #include <cwidget/generic/util/exception.h>
 
 #include <sqlite3.h>
 
-#include <boost/make_shared.hpp>
 #include <boost/multi_index_container.hpp>
 #include <boost/multi_index/hashed_index.hpp>
 #include <boost/multi_index/sequenced_index.hpp>
 #include <boost/multi_index/member.hpp>
-#include <boost/shared_ptr.hpp>
-#include <boost/unordered_set.hpp>
+
+#include <memory>
+#include <unordered_set>
 
 // C++ wrapper for sqlite to handle tracking and releasing resources.
 
@@ -77,10 +81,10 @@ namespace aptitude
       // constructor and destructor of the statement class.  When the
       // database itself is destroyed, this is used to invalidate all
       // the statement objects.
-      boost::unordered_set<statement *> active_statements;
+      std::unordered_set<statement *> active_statements;
 
       // Similarly, a set of active blob objects.
-      boost::unordered_set<blob *> active_blobs;
+      std::unordered_set<blob *> active_blobs;
 
 
 
@@ -94,10 +98,10 @@ namespace aptitude
       struct statement_cache_entry
       {
 	std::string sql;
-	boost::shared_ptr<statement> stmt;
+	std::shared_ptr<statement> stmt;
 
 	statement_cache_entry(const std::string &_sql,
-			      const boost::shared_ptr<statement> &_stmt)
+			      const std::shared_ptr<statement> &_stmt)
 	  : sql(_sql), stmt(_stmt)
 	{
 	}
@@ -155,7 +159,7 @@ namespace aptitude
 	{
 	}
 
-	const boost::shared_ptr<statement> &get_statement() const { return entry.stmt; }
+	const std::shared_ptr<statement> &get_statement() const { return entry.stmt; }
 	const statement_cache_entry &get_entry() const { return entry; }
 
 	~statement_proxy_impl();
@@ -188,12 +192,12 @@ namespace aptitude
        *
        *  See the sqlite3_open documentation for details.
        */
-      static boost::shared_ptr<db>
+      static std::shared_ptr<db>
       create(const std::string &filename,
 	     int flags = SQLITE_OPEN_READWRITE | SQLITE_OPEN_CREATE,
 	     const char *vfs = NULL)
       {
-	return boost::shared_ptr<db>(new db(filename, flags, vfs));
+	return std::shared_ptr<db>(new db(filename, flags, vfs));
       }
 
       /** \brief Close the encapsulated database. */
@@ -252,11 +256,11 @@ namespace aptitude
        */
       class statement_proxy
       {
-	boost::shared_ptr<statement_proxy_impl> impl;
+	std::shared_ptr<statement_proxy_impl> impl;
 
 	friend class db;
 
-	statement_proxy(const boost::shared_ptr<statement_proxy_impl> &_impl)
+	statement_proxy(const std::shared_ptr<statement_proxy_impl> &_impl)
 	  : impl(_impl)
 	{
 	}
@@ -372,8 +376,6 @@ namespace aptitude
       friend class db::statement_proxy_impl;
 
       statement(db &_parent, sqlite3_stmt *_handle);
-      template<typename A, typename B, typename C>
-      friend boost::shared_ptr<A> boost::make_shared(const B &, const C &);
 
       /** \brief Throw an exception if there isn't result data ready
        *  to be read.
@@ -401,16 +403,10 @@ namespace aptitude
 
       /** \brief Prepare an SQL statement.
        */
-      static boost::shared_ptr<statement>
+      static std::shared_ptr<statement>
       prepare(db &parent,
 	      const std::string &sql);
 
-      /** \brief Prepare an SQL statement.
-       */
-      static boost::shared_ptr<statement>
-      prepare(db &parent,
-	      const char *sql);
-
       /** \brief Return to the beginning of the statement's result set
        *  and discard parameter bindings.
        */
@@ -451,7 +447,6 @@ namespace aptitude
        */
       void bind_int(int parameter_idx, int value);
 
-
       /** \brief Bind a 64-bit integer to a parameter.
        *
        *  \param parameter_idx  The one-based index of the parameter to set.
@@ -565,8 +560,6 @@ namespace aptitude
       friend class db;
 
       blob(db &_parent, sqlite3_blob *_handle);
-      template<typename A, typename B, typename C>
-      friend boost::shared_ptr<A> boost::make_shared(const B &, const C &);
 
     public:
       /** \brief Open an existing BLOB.
@@ -581,7 +574,7 @@ namespace aptitude
        *                      read-only; otherwise it will be opened
        *                      read-write.
        */
-      static boost::shared_ptr<blob>
+      static std::shared_ptr<blob>
       open(db &parent,
 	   const std::string &databaseName,
 	   const std::string &table,
